# frozen_string_literal: true

require 'happymapper'
require_relative 'node'
require_relative './broker'
require_relative './location'
require_relative './company'
require_relative './sector'
require_relative './entitlement_group'
require_relative './product_group'
require_relative './participant'
require_relative './helper/normalized_string'

module ForwardCalendar
  class Event < Node
    include HappyMapper
    tag 'event'

    has_many :locations, Location, tag: 'eventLocation'
    has_many :entitlement_groups, EntitlementGroup, tag: 'entitlementGroup'
    has_many :product_groups, ProductGroup, tag: 'productGroup'
    has_many :companies, Company, tag: 'company', xpath: 'companies'
    has_many :broker_participants, Participant, tag: 'participant', xpath: 'brokerParticipants'
    has_many :third_party_participants, Participant, tag: 'participant', xpath: 'thirdPartyParticipants'
    has_many :sectors, Sector, tag: 'sector', xpath: 'sectors'
    has_one :broker, Broker, tag: 'broker'

    element :id, Integer, tag: 'eventID'
    element :type, Helper::NormalizedString, tag: 'eventType'
    element :title, String, tag: 'eventTitle'
    element :status, Helper::NormalizedString, tag: 'eventStatus'
    element :description, String, tag: 'eventDescription'
    element :start, Date, tag: 'start'
    element :end, Date, tag: 'end'
    element :url, String, tag: 'URL'
    element :transcript_url, String, tag: 'transcriptURL'
  end
end
